@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,9 +19,9 @@
 
 """Provides the interface to the AT-SPI Registry."""
 
-__id__        = "$Id: atspi.py 1852 2006-12-21 13:27:19Z wwalker $"
-__version__   = "$Revision: 1852 $"
-__date__      = "$Date: 2006-12-21 08:27:19 -0500 (Thu, 21 Dec 2006) $"
+__id__        = "$Id: atspi.py 2047 2007-02-23 01:52:09Z lmonsanto $"
+__version__   = "$Revision: 2047 $"
+__date__      = "$Date: 2007-02-22 20:52:09 -0500 (Thu, 22 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -64,31 +64,6 @@ class Event:
     object with their own attributes.
     """
 
-    def getAnyData(e):
-        """Returns the any_data field, compensating for any
-        differences between pre-1.7.0 and post-1.7.0 implementations
-        of the AT-SPI."""
-
-        # [[[TODO: WDW - HACK because AT-SPI 1.7.0 has
-        # introduced a binary incompatibility where the
-        # "any_data" of the event has changed from being a
-        # real "any_data" to an EventDetails structure that
-        # holds "any_data."  This check here helps us deal
-        # with the case where we might be talking to a
-        # pre-1.7.0 implementation or a 1.7.0+ implementation.
-        # What we're doing is just checking the CORBA typecode
-        # (as a string) to see if the type of the "any_data"
-        # field is this new structure.  If it is, we pull the
-        # "any_data" field from it.  If it isn't, we get the
-        # "any_data" field as we normally would.]]]
-        #
-        if e.any_data and (e.any_data.typecode().name) == "EventDetails":
-            return e.any_data.value().any_data
-        else:
-            return e.any_data
-
-    getAnyData = staticmethod(getAnyData)
-
     def __init__(self, e=None):
         if e:
             self.source   = Accessible.makeAccessible(e.source)
@@ -108,6 +83,21 @@ class Event:
                         details.host_application)
             else:
                 self.any_data = e.any_data
+
+            # We need to make sure we reference any object that comes
+            # to us via an any_data because we process events
+            # asynchronously.  If we don't reference them, we may
+            # end up with OBJECT_NOT_EXIST errors.  Please see
+            # http://bugzilla.gnome.org/show_bug.cgi?id=395749 for
+            # more information.
+            #
+            if self.type == "object:active-descendant-changed":
+                self.any_data = Accessible.makeAccessible(
+                    self.any_data.value())
+            elif self.type == "object:text-changed:insert":
+                self.any_data = self.any_data.value()
+            elif self.type == "object:text-changed:delete":
+                self.any_data = self.any_data.value()
         else:
             self.source   = None
             self.type     = None
@@ -853,7 +843,7 @@ class Accessible:
 
         description = self.accessible.description
 
-        if description and settings.cacheValues:
+        if description and settings.cacheValues and settings.cacheDescriptions:
             self.description = description
 
         return description
@@ -1286,6 +1276,17 @@ class Accessible:
 
         return value
 
+    def __get_attributes(self):
+        """Returns an Accessibility_AttributeSet of the object.
+        """
+
+        try:
+            attributes = self.accessible.getAttributes()
+        except:
+            attributes = None
+
+        return attributes
+
     def __getattr__(self, attr):
         """Created virtual attributes for the Accessible object to make
         the syntax a bit nicer (e.g., acc.name rather than acc.name()).
@@ -1339,6 +1340,8 @@ class Accessible:
             return self.__get_text()
         elif attr == "value":
             return self.__get_value()
+        elif attr == "attributes":
+            return self.__get_attributes()
         elif attr.startswith('__') and attr.endswith('__'):
             raise AttributeError, attr
         else:
@@ -1371,7 +1374,12 @@ class Accessible:
                 newChild.app = self.app
 
         if not newChild:
-            debug.println(debug.LEVEL_FINEST,
+            # The problem with a child not existing is a bad one.
+            # We want to issue a warning and we also want to know
+            # where it happens.
+            #
+            debug.printStack(debug.LEVEL_WARNING)
+            debug.println(debug.LEVEL_WARNING,
                           "Child at index %d is not an Accessible" % index)
 
         return newChild
