@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 2174 2007-03-14 19:33:59Z richb $"
-__version__   = "$Revision: 2174 $"
-__date__      = "$Date: 2007-03-14 15:33:59 -0400 (Wed, 14 Mar 2007) $"
+__id__        = "$Id: braille.py 2338 2007-05-02 16:32:43Z wwalker $"
+__version__   = "$Revision: 2338 $"
+__date__      = "$Date: 2007-05-02 12:32:43 -0400 (Wed, 02 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -44,9 +44,12 @@ import atspi
 #
 try:
     import brlapi
+    import gobject
+
     brlAPI = None
     useBrlAPIBindings = True
     brlAPIRunning = False
+    brlAPISourceId = 0
 except:
     import brl
     useBrlAPIBindings = False
@@ -158,12 +161,50 @@ BRL_FLG_REPEAT_DELAY  = 0x400000
 # ATM, the ones used in default.py are:
 #
 command_name = {}
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the left.
+#
 command_name[CMD_FWINLT]   = _("Line Left")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the right.
+#
 command_name[CMD_FWINRT]   = _("Line Right")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls up.
+#
 command_name[CMD_LNUP]     = _("Line Up")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls down.
+#
 command_name[CMD_LNDN]     = _("Line Down")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the top left of the
+# window.
+#
 command_name[CMD_TOP_LEFT] = _("Top Left")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the bottom right of
+# the window.
+#
 command_name[CMD_BOT_LEFT] = _("Bottom Right")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to position containing
+# the cursor.
+#
 command_name[CMD_HOME]     = _("Cursor Position")
 
 # The size of the physical display (width, height).  The coordinate system of
@@ -894,9 +935,9 @@ def _processBrailleEvent(command):
 
     return consumed
 
-def _brlAPIKeyReader():
+def _brlAPIKeyReader(source, condition):
         """Method to read a key from the BrlAPI bindings.  This is a
-        gidle handler.
+        gobject IO watch handler.
         """
         key = brlAPI.readKey(False)
         if key:
@@ -1002,10 +1043,11 @@ def init(callback=None, tty=7):
 
     if useBrlAPIBindings:
         try:
-            import gobject
-            gobject.threads_init()
             global brlAPI
             global brlAPIRunning
+            global brlAPISourceId
+
+            gobject.threads_init()
             brlAPI = brlapi.Connection()
 
             try:
@@ -1013,7 +1055,6 @@ def init(callback=None, tty=7):
                 windowPath = os.environ["WINDOWPATH"]
                 brlAPI.enterTtyModeWithPath()
                 brlAPIRunning = True
-                gobject.idle_add(_brlAPIKeyReader)
                 debug.println(\
                     debug.LEVEL_CONFIGURATION,
                     "Braille module has been initialized using WINDOWPATH=" \
@@ -1021,10 +1062,12 @@ def init(callback=None, tty=7):
             except:
                 brlAPI.enterTtyMode(tty)
                 brlAPIRunning = True
-                gobject.idle_add(_brlAPIKeyReader)
                 debug.println(\
                     debug.LEVEL_CONFIGURATION,
                     "Braille module has been initialized using tty=%d" % tty)
+            brlAPISourceId = gobject.io_add_watch(brlAPI.fileDescriptor,
+                                                  gobject.IO_IN,
+                                                  _brlAPIKeyReader)
         except:
             debug.printException(debug.LEVEL_FINEST)
             return False
@@ -1070,9 +1113,13 @@ def shutdown():
         return False
 
     global brlAPIRunning
+    global brlAPISourceId
+
     if useBrlAPIBindings:
         if brlAPIRunning:
             brlAPIRunning = False
+            gobject.source_remove(brlAPISourceId)
+            brlAPISourceId = 0
             brlAPI.leaveTtyMode()
     else:
         brl.shutdown()
