@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 2223 2007-03-28 17:06:38Z wwalker $"
-__version__   = "$Revision: 2223 $"
-__date__      = "$Date: 2007-03-28 13:06:38 -0400 (Wed, 28 Mar 2007) $"
+__id__        = "$Id: braillegenerator.py 2343 2007-05-03 20:51:02Z richb $"
+__version__   = "$Revision: 2343 $"
+__date__      = "$Date: 2007-05-03 16:51:02 -0400 (Thu, 03 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -708,6 +708,16 @@ class BrailleGenerator:
         text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
         text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
+        # OpenOffice check menu items currently have a role of "menu item"
+        # rather then "check menu item", so we need to test if one of the
+        # states is CHECKED. If it is, then add that in to the braille
+        # display output. Note that we can't tell if this is a "check
+        # menu item" that is currently unchecked and braille that state. 
+        # See Orca bug #433398 for more details.
+        #
+        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            text = self._script.appendString(text, "<x>")
+
         if obj == orca_state.locusOfFocus:
             text = self._script.appendString(text, self._getTextForAvailability(obj))
             text = self._script.appendString(text,
