@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 2298 2007-04-18 18:40:05Z wwalker $"
-__version__   = "$Revision: 2298 $"
-__date__      = "$Date: 2007-04-18 14:40:05 -0400 (Wed, 18 Apr 2007) $"
+__id__        = "$Id: orca.py 2371 2007-05-11 15:28:14Z richb $"
+__version__   = "$Revision: 2371 $"
+__date__      = "$Date: 2007-05-11 11:28:14 -0400 (Fri, 11 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -667,10 +667,39 @@ def _processKeyboardEvent(event):
 
     keyboardEvent = KeyboardEvent(event)
 
-    # See if this is one of our special Orca modifiers (e.g., "Insert")
+    # See if this is one of our special Orca modifier keys.
     #
-    orcaModifierKeys = settings.orcaModifierKeys
-    isOrcaModifier = orcaModifierKeys.count(keyboardEvent.event_string) > 0
+    # [[[TODO: WDW - Note that just looking at the keycode should
+    # suffice, but there is a "feature" in the Java Access Bridge
+    # where it chooses to emit Java platform-independent keycodes
+    # instead of the keycodes for the base platform:
+    #
+    # http://bugzilla.gnome.org/show_bug.cgi?id=106004
+    # http://bugzilla.gnome.org/show_bug.cgi?id=318615
+    #
+    # So...we need to workaround this problem.
+    #
+    # If you make the following expression True we will get a positive
+    # match for all keysyms associated with a given keysym specified
+    # as an Orca modifier key.
+    #
+    # For example, assume the Orca modifier is set to \ for some
+    # reason.  The key that has \ on it produces \ without the Shift
+    # key and | with the Shift key.  If the following expression is
+    # True, both the \ and | will be viewed as the Orca modifier.  If
+    # the following expression is False, only the \ will be viewed as
+    # the Orca modifier (i.e., Shift+\ will still function as the |
+    # character).  In general, I think we want to avoid sucking in all
+    # possible keysyms because it can have unexpected results.]]]
+    #
+    if False:
+        allPossibleKeysyms = []
+        for keysym in settings.orcaModifierKeys:
+            allPossibleKeysyms.extend(keybindings.getAllKeysyms(keysym))
+    else:
+        allPossibleKeysyms = settings.orcaModifierKeys
+
+    isOrcaModifier = allPossibleKeysyms.count(keyboardEvent.event_string) > 0
 
     if event.type == atspi.Accessibility.KEY_PRESSED_EVENT:
         # Key presses always interrupt speech.
@@ -734,6 +763,14 @@ def _processKeyboardEvent(event):
 
     orca_state.lastInputEvent = keyboardEvent
 
+    # If this is a key event for a non-modifier key, save a handle to it.
+    # This is needed to help determine user actions when a multi-key chord 
+    # has been pressed, and we might get the key events in different orders.
+    # See comment #15 of bug #435201 for more details.
+    #
+    if not _isModifierKey(keyboardEvent.event_string):
+        orca_state.lastNonModifierKeyEvent = keyboardEvent
+
     return consumed or isOrcaModifier
 
 ########################################################################
@@ -879,9 +916,30 @@ def loadUserSettings(script=None, inputEvent=None):
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Magnification module has NOT been initialized.")
 
+    # We don't want the Caps_Lock modifier to act as a locking
+    # modifier if it used as the Orca modifier key.  In addition, if
+    # the KP_Insert key is used as the Orca modifier key, we want to
+    # make sure we clear any other keysyms that might be in use on
+    # that key since we won't be able to detect them as being the Orca
+    # modifier key.  For example, KP_Insert produces "KP_Insert" when
+    # pressed by itself, but Shift+KP_Insert produces "0".
+    #
+    # The original values are saved/reset in the orca shell script.
+    #
+    # [[[TODO: WDW - we probably should just to a 'xmodmap -e "%s = %s"'
+    # for all of the orcaModifierKeys, but saving/restoring the values
+    # becomes a little more difficult.  If we could assume a writeable
+    # filesystem (we cannot), we could do a 'xmodmap -pke > /tmp/foo'
+    # to save the keymap and a 'xmodmap /tmp/foo' to restore it.
+    # For now, we'll just look at the Orca modifier keys we support
+    # (Caps Lock, KP_Insert, and Insert).]]]
+    #
     for keyName in settings.orcaModifierKeys:
         if keyName == "Caps_Lock":
             os.system('xmodmap -e "clear Lock"')
+        if keyName in ["Caps_Lock", "KP_Insert", "Insert"]:
+            command = 'xmodmap -e "keysym %s = %s"' % (keyName, keyName)
+            os.system(command)
 
     if _currentPresentationManager >= 0:
         _PRESENTATION_MANAGERS[_currentPresentationManager].activate()
@@ -892,6 +950,26 @@ def loadUserSettings(script=None, inputEvent=None):
 
     return True
 
+def _showAppPreferencesGUI(script=None, inputEvent=None):
+    """Displays the user interace to configure the settings for a
+    specific applications within Orca and set up those app-specific
+    user preferences using a GUI.
+
+    Returns True to indicate the input event has been consumed.
+    """
+
+    try:
+        module = __import__(settings.appGuiPreferencesModule,
+                            globals(),
+                            locals(),
+                            [''])
+        module.showPreferencesUI()
+    except:
+        debug.printException(debug.LEVEL_SEVERE)
+        pass
+
+    return True
+
 def _showPreferencesGUI(script=None, inputEvent=None):
     """Displays the user interace to configure Orca and set up
     user preferences using a GUI.
