@@ -19,9 +19,9 @@
 
 """Provides a custom script for gcalctool."""
 
-__id__        = "$Id: gcalctool.py 2141 2007-03-07 21:00:32Z richb $"
-__version__   = "$Revision: 2141 $"
-__date__      = "$Date: 2007-03-07 16:00:32 -0500 (Wed, 07 Mar 2007) $"
+__id__        = "$Id: gcalctool.py 2371 2007-05-11 15:28:14Z richb $"
+__version__   = "$Revision: 2371 $"
+__date__      = "$Date: 2007-05-11 11:28:14 -0400 (Fri, 11 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -159,7 +159,7 @@ class Script(default.Script):
                                    input_event.KeyboardEvent)):
                 return
 
-            if (orca_state.lastInputEvent.event_string == "space") \
-                   or (orca_state.lastInputEvent.event_string == "Return") \
-                   or (orca_state.lastInputEvent.event_string == "="):
+            if (orca_state.lastNonModifierKeyEvent.event_string == "space") \
+                   or (orca_state.lastNonModifierKeyEvent.event_string == "Return") \
+                   or (orca_state.lastNonModifierKeyEvent.event_string == "="):
                 speech.speak(contents)
