@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2292 2007-04-17 22:04:51Z wwalker $"
-__version__   = "$Revision: 2292 $"
-__date__      = "$Date: 2007-04-17 18:04:51 -0400 (Tue, 17 Apr 2007) $"
+__id__        = "$Id: settings.py 2366 2007-05-09 21:22:51Z richb $"
+__version__   = "$Revision: 2366 $"
+__date__      = "$Date: 2007-05-09 17:22:51 -0400 (Wed, 09 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -36,7 +36,7 @@ tty = 7
 
 # Whether tool tips can be presented.
 #
-presentToolTips = False
+canPresentToolTips = False
 
 try:
     # This can fail due to gtk not being available.  We want to
@@ -67,7 +67,7 @@ try:
     current_gtk_version  = (100000 * gtk.gtk_version[0]) + \
                            (1000 * gtk.gtk_version[1]) + \
                             gtk.gtk_version[2]
-    presentToolTips = (current_gtk_version >= minimum_gtk_version)
+    canPresentToolTips = (current_gtk_version >= minimum_gtk_version)
 except:
     pass
 
@@ -125,6 +125,7 @@ userCustomizableSettings = [
     "verbalizePunctuationStyle",
     "showMainWindow",
     "quitOrcaNoConfirmation",
+    "presentToolTips",
     "sayAllStyle",
     "keyboardLayout",
     "speakBlankLines",
@@ -142,6 +143,7 @@ mainWindowModule = "orca_gui_main"
 #
 guiPreferencesModule    = "orca_gui_prefs"
 consolePreferencesModule= "orca_console_prefs"
+appGuiPreferencesModule = "app_gui_prefs"
 
 # The name of the module that hold the user interface for quitting Orca.
 # This module is expected to have the method, showQuitUI, which will
@@ -371,6 +373,10 @@ showMainWindow          = True
 #
 quitOrcaNoConfirmation  = False
 
+# Whether the user wants tooltips presented or not.
+#
+presentToolTips = False and canPresentToolTips
+
 # Keyboard layout options (see keyboardLayout).
 #
 GENERAL_KEYBOARD_LAYOUT_DESKTOP = 1
